@@ -12,7 +12,7 @@ use Perinci::Sub::Util qw(gen_modified_sub);
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-11-16'; # DATE
 our $DIST = 'App-DownloadsDirUtils'; # DIST
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 our %SPEC;
 
@@ -63,13 +63,14 @@ MARKDOWN
             },
             exclude_filename_pattern => sub {
                 my $arg_spec = shift;
-                $arg_spec->{default} = qr/\.part\z/;
+                $arg_spec->{default} = '/\.part\z/';
             },
         },
         output_code => sub {
             no strict 'refs'; ## no critic: TestingAndDebugging::ProhibitNoStrict
             my %args = @_;
             $args{dirs} //= scalar list_downloads_dirs();
+            $args{exclude_filename_pattern} //= qr/\.part\z/;
             &{"App::FileSortUtils::$which"}(%args);
         },
     );
@@ -92,7 +93,7 @@ App::DownloadsDirUtils - Utilities related to downloads directories
 
 =head1 VERSION
 
-This document describes version 0.001 of App::DownloadsDirUtils (from Perl distribution App-DownloadsDirUtils), released on 2023-11-16.
+This document describes version 0.002 of App::DownloadsDirUtils (from Perl distribution App-DownloadsDirUtils), released on 2023-11-16.
 
 =head1 DESCRIPTION
 
@@ -149,7 +150,7 @@ Do not ignore entries starting with .
 
 Directory to sort files of, defaults to current directory.
 
-=item * B<exclude_filename_pattern> => I<re_from_str> (default: qr(\.part\z))
+=item * B<exclude_filename_pattern> => I<re_from_str> (default: "/\\.part\\z/")
 
 Exclude filenames that match a regex pattern.
 
@@ -230,7 +231,7 @@ Do not ignore entries starting with .
 
 Directory to sort files of, defaults to current directory.
 
-=item * B<exclude_filename_pattern> => I<re_from_str> (default: qr(\.part\z))
+=item * B<exclude_filename_pattern> => I<re_from_str> (default: "/\\.part\\z/")
 
 Exclude filenames that match a regex pattern.
 
@@ -311,7 +312,7 @@ Do not ignore entries starting with .
 
 Directory to sort files of, defaults to current directory.
 
-=item * B<exclude_filename_pattern> => I<re_from_str> (default: qr(\.part\z))
+=item * B<exclude_filename_pattern> => I<re_from_str> (default: "/\\.part\\z/")
 
 Exclude filenames that match a regex pattern.
 
@@ -404,7 +405,7 @@ Do not ignore entries starting with .
 
 Directory to sort files of, defaults to current directory.
 
-=item * B<exclude_filename_pattern> => I<re_from_str> (default: qr(\.part\z))
+=item * B<exclude_filename_pattern> => I<re_from_str> (default: "/\\.part\\z/")
 
 Exclude filenames that match a regex pattern.
 
@@ -481,7 +482,7 @@ Do not ignore entries starting with .
 
 Directory to sort files of, defaults to current directory.
 
-=item * B<exclude_filename_pattern> => I<re_from_str> (default: qr(\.part\z))
+=item * B<exclude_filename_pattern> => I<re_from_str> (default: "/\\.part\\z/")
 
 Exclude filenames that match a regex pattern.
 
@@ -558,7 +559,7 @@ Do not ignore entries starting with .
 
 Directory to sort files of, defaults to current directory.
 
-=item * B<exclude_filename_pattern> => I<re_from_str> (default: qr(\.part\z))
+=item * B<exclude_filename_pattern> => I<re_from_str> (default: "/\\.part\\z/")
 
 Exclude filenames that match a regex pattern.
 
